==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/table/lang/is.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'is', {
	border: 'Breidd ramma',
	caption: 'Titill',
	cell: {
		menu: 'Reitur',
		insertBefore: 'Skjóta inn reiti fyrir aftan',
		insertAfter: 'Skjóta inn reiti fyrir framan',
		deleteCell: 'Fella reit',
		merge: 'Sameina reiti',
		mergeRight: 'Sameina til hægri',
		mergeDown: 'Sameina niður á við',
		splitHorizontal: 'Kljúfa reit lárétt',
		splitVertical: 'Kljúfa reit lóðrétt',
		title: 'Cell Properties',
		cellType: 'Cell Type',
		rowSpan: 'Rows Span',
		colSpan: 'Columns Span',
		wordWrap: 'Word Wrap',
		hAlign: 'Horizontal Alignment',
		vAlign: 'Vertical Alignment',
		alignBaseline: 'Baseline',
		bgColor: 'Background Color',
		borderColor: 'Border Color',
		data: 'Data',
		header: 'Header',
		yes: 'Yes',
		no: 'No',
		invalidWidth: 'Cell width must be a number.',
		invalidHeight: 'Cell height must be a number.',
		invalidRowSpan: 'Rows span must be a whole number.',
		invalidColSpan: 'Columns span must be a whole number.',
		chooseColor: 'Choose'
	},
	cellPad: 'Reitaspássía',
	cellSpace: 'Bil milli reita',
	column: {
		menu: 'Dálkur',
		insertBefore: 'Skjóta inn dálki vinstra megin',
		insertAfter: 'Skjóta inn dálki hægra megin',
		deleteColumn: 'Fella dálk'
	},
	columns: 'Dálkar',
	deleteTable: 'Fella töflu',
	headers: 'Fyrirsagnir',
	headersBoth: 'Hvort tveggja',
	headersColumn: 'Fyrsti dálkur',
	headersNone: 'Engar',
	headersRow: 'Fyrsta röð',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Border size must be a number.', // MISSING
	invalidCellPadding: 'Cell padding must be a positive number.', // MISSING
	invalidCellSpacing: 'Cell spacing must be a positive number.', // MISSING
	invalidCols: 'Number of columns must be a number greater than 0.', // MISSING
	invalidHeight: 'Table height must be a number.', // MISSING
	invalidRows: 'Number of rows must be a number greater than 0.', // MISSING
	invalidWidth: 'Table width must be a number.', // MISSING
	menu: 'Eigindi töflu',
	row: {
		menu: 'Röð',
		insertBefore: 'Skjóta inn röð fyrir ofan',
		insertAfter: 'Skjóta inn röð fyrir neðan',
		deleteRow: 'Eyða röð'
	},
	rows: 'Raðir',
	summary: 'Áfram',
	title: 'Eigindi töflu',
	toolbar: 'Tafla',
	widthPc: 'prósent',
	widthPx: 'myndeindir',
	widthUnit: 'width unit' // MISSING
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/is.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'is', {
	border: 'Breidd ramma',
	caption: 'Titill',
	cell: {
		menu: 'Reitur',
		insertBefore: 'Skjóta inn reiti fyrir aftan',
		insertAfter: 'Skjóta inn reiti fyrir framan',
		deleteCell: 'Fella reit',
		merge: 'Sameina reiti',
		mergeRight: 'Sameina til hægri',
		mergeDown: 'Sameina niður á við',
		splitHorizontal: 'Kljúfa reit lárétt',
		splitVertical: 'Kljúfa reit lóðrétt',
		title: 'Cell Properties',
		cellType: 'Cell Type',
		rowSpan: 'Rows Span',
		colSpan: 'Columns Span',
		wordWrap: 'Word Wrap',
		hAlign: 'Horizontal Alignment',
		vAlign: 'Vertical Alignment',
		alignBaseline: 'Baseline',
		bgColor: 'Background Color',
		borderColor: 'Border Color',
		data: 'Data',
		header: 'Header',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Yes',
		no: 'No',
		invalidWidth: 'Cell width must be a number.',
		invalidHeight: 'Cell height must be a number.',
		invalidRowSpan: 'Rows span must be a whole number.',
		invalidColSpan: 'Columns span must be a whole number.',
		chooseColor: 'Choose'
	},
	cellPad: 'Reitaspássía',
	cellSpace: 'Bil milli reita',
	column: {
		menu: 'Dálkur',
		insertBefore: 'Skjóta inn dálki vinstra megin',
		insertAfter: 'Skjóta inn dálki hægra megin',
		deleteColumn: 'Fella dálk'
	},
	columns: 'Dálkar',
	deleteTable: 'Fella töflu',
	headers: 'Fyrirsagnir',
	headersBoth: 'Hvort tveggja',
	headersColumn: 'Fyrsti dálkur',
	headersNone: 'Engar',
	headersRow: 'Fyrsta röð',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Border size must be a number.', // MISSING
	invalidCellPadding: 'Cell padding must be a positive number.', // MISSING
	invalidCellSpacing: 'Cell spacing must be a positive number.', // MISSING
	invalidCols: 'Number of columns must be a number greater than 0.', // MISSING
	invalidHeight: 'Table height must be a number.', // MISSING
	invalidRows: 'Number of rows must be a number greater than 0.', // MISSING
	invalidWidth: 'Table width must be a number.', // MISSING
	menu: 'Eigindi töflu',
	row: {
		menu: 'Röð',
		insertBefore: 'Skjóta inn röð fyrir ofan',
		insertAfter: 'Skjóta inn röð fyrir neðan',
		deleteRow: 'Eyða röð'
	},
	rows: 'Raðir',
	summary: 'Áfram',
	title: 'Eigindi töflu',
	toolbar: 'Tafla',
	widthPc: 'prósent',
	widthPx: 'myndeindir',
	widthUnit: 'width unit' // MISSING
} );
